@@ -73,7 +73,9 @@ class Hub:
             else:
                 while self.chats.get(environ.get('QUERY_STRING')[3:])==[]:
                     pass
-                return [json.dumps(self.chats.get(environ.get('QUERY_STRING')[3:])).encode()]
+                msg=json.dumps(self.chats.get(environ.get('QUERY_STRING')[3:])).encode()
+                self.chats[environ.get('QUERY_STRING')[3:]]=[]
+                return [msg]
     def Message(self, msg, client):
         logger.warn('client '+str(client)+' : '+msg)
     def Client(self, client):
@@ -86,7 +88,7 @@ class Hub:
     def ws(self, environ, start_response):
         self.client_counter+=1
         _id='ws'+str(self.client_counter)
-        self.chats[_id]=[]
+        self.chats[_id]=environ.get('wsgi.websocket')
         ws=environ.get('wsgi.websocket')
         self.async_run(self.Client, [_id])  
         while True:
